Xprinter class

Annotations

Constructors

Xprinter()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<void>
Close printer connection
connectToPrinter(String macAddress) → Future<bool>
Connect to a specific printer by MAC address
exitSdk() → Future<void>
Exit SDK and release resources
getBluetoothDevices() → Future<List<BluetoothPrinterDevice>>
Get list of paired Bluetooth devices
getPlatformVersion() → Future<String?>
Get platform version
hasBluetoothPermissions() → Future<bool>
Check if all required Bluetooth permissions are granted
initialize() → Future<bool>
Initialize the printer SDK
isPrinterConnected() → Future<bool>
Check if printer is currently connected
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printBitmap(String filePath) → Future<bool>
Print a bitmap file
reconnectLastPrinter() → Future<bool>
Reconnect to last used printer
requestBluetoothPermissions() → Future<bool>
Request Bluetooth permissions
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited