MethodChannelXprinter class

An implementation of XprinterPlatform that uses method channels.

Inheritance

Constructors

MethodChannelXprinter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateStream → Stream<Map<String, dynamic>>
Stream of printer state changes
no setter

Methods

close() → Future<void>
Close printer connection
override
connectToPrinter(String macAddress) → Future<bool>
Connect to a specific printer by MAC address
override
dispose() → void
Dispose resources
exitSdk() → Future<void>
Exit SDK and release resources
override
getBluetoothDevices() → Future<List<BluetoothPrinterDevice>>
Get list of paired Bluetooth devices
override
getPlatformVersion() → Future<String?>
override
hasBluetoothPermissions() → Future<bool>
Check if all required Bluetooth permissions are granted
override
initialize() → Future<bool>
Initialize the printer SDK
override
isPrinterConnected() → Future<bool>
Check if printer is currently connected
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printBitmap(String filePath) → Future<bool>
Print a bitmap file
override
reconnectLastPrinter() → Future<bool>
Reconnect to last used printer
override
requestBluetoothPermissions() → Future<bool>
Request Bluetooth permissions
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited